@@ -5,5 +5,5 @@ from .mongodb import MongoDBStorageBackend
 
 BACKENDS: Dict[str, Any] = {
     "sqlite": {"object": SqliteStorageBackend, "params": ["db_path"]},
-    "mongodb": {"object": MongoDBStorageBackend, "params": ["db_string"]},
+    "mongodb": {"object": MongoDBStorageBackend, "params": ["db_string", "collection_name"]},
 }
