@@ -15,6 +15,7 @@ class MongoDBStorageBackend(BaseStorageBackend):
 
     def __init__(self, params: Dict[str, str]):
         db_string = params.get("db_string")
+        self.collection_name = params.get("collection_name", "tweets")
         LOG.debug(f"DB connection string: {db_string}")
         self.client = pymongo.MongoClient(db_string)
         self.init_backend()
@@ -23,4 +24,4 @@ class MongoDBStorageBackend(BaseStorageBackend):
         self.db = self.client.twistream
 
     def persist_status(self, status: Status) -> None:
-        self.db.tweets.insert_one(status._json)
+        self.db[self.collection_name].insert_one(status._json)
